Resources
=========

Groups
------

* Software Quality Assurance & Testing (Stack Exchange):
    http://sqa.stackexchange.com/
* webdriver (reddit):
    https://www.reddit.com/r/webdriver
* selenium (reddit):
    https://www.reddit.com/r/selenium
* Quality Assurance (reddit):
    https://www.reddit.com/r/QualityAssurance
* Selenium-users (google groups):
    https://groups.google.com/forum/#!forum/selenium-users
* Selenium-developers (google groups):
    https://groups.google.com/forum/#!forum/selenium-developers
* webdriver (google groups):
    https://groups.google.com/forum/#!forum/webdriver
* Selenium and Python (LinkedIn):
    https://www.linkedin.com/grp/home?gid=2305920&trk=my_groups-tile-grp
* Selenium Experts (LinkedIn):
    https://www.linkedin.com/grp/home?gid=2074523&trk=my_groups-tile-flipgrp
* Selenium Testing (LinkedIn):
    https://www.linkedin.com/grp/home?gid=2102114&trk=my_groups-tile-grp
* Selenium Grid (LinkedIn):
    https://www.linkedin.com/grp/home?gid=4368621&trk=my_groups-tile-grp
* Selenium 2.0 and WebDriver (LinkedIn):
    https://www.linkedin.com/grp/home?gid=3985798&trk=my_groups-tile-flipgrp
* Selenium WebDriver (LinkedIn):
    https://www.linkedin.com/grp/home?gid=4067187&trk=my_groups-tile-flipgrp
* Selenium WebDriver & Appium (LinkedIn): 
    https://www.linkedin.com/grp/home?gid=6669152&trk=my_groups-tile-grp
* Selenium irc:
    http://elementalselenium.com/tips/20-irc-chat

Conf / Presentation
-------------------

* Python for Blackbox Testers by Sajnikanth Suriyanarayanan | PyCon SG 2013:
    https://www.youtube.com/watch?v=2ggWbGLkBPk&feature=youtu.be
* Selenium Conf:
    https://www.youtube.com/user/seleniumconf/videos
* Agile India:
    https://www.youtube.com/user/AgileIndia2012/videos

Tools / Frameworks / Library
----------------------------

* Awesome Python Test Automation: 
    https://github.com/atinfo/awesome-test-automation/blob/master/python-test-automation.md
* AutoItDriverServer:
    https://github.com/daluu/AutoItDriverServer 
* RedGlass:
    https://github.com/bimech/domreactor-redglass 
* SinonJS:
    http://sinonjs.org/ 
* Holmium:
    https://holmiumcore.readthedocs.org/en/latest/ 
* Faker:
    https://github.com/joke2k/faker 
* Splinter:
    http://splinter.readthedocs.org/en/latest/ 
* Saunter:
    https://github.com/Element-34/py.saunter/tree/master/saunter 
* Gremlin:
    https://github.com/marmelab/gremlins.js

Grid
----

* Selenium-Grid-Extras:
    https://github.com/groupon/Selenium-Grid-Extras
* SeLion:
    https://github.com/paypal/SeLion

Chrome
------

* Chrome Driver:
    https://sites.google.com/a/chromium.org/chromedriver/home
* Web Performance Testing with WebDriver:
    https://gist.github.com/klepikov/5457750 
* Chrome capabilities:
    https://sites.google.com/a/chromium.org/chromedriver/capabilities
